@@ -231,7 +231,7 @@ class MainWindow(QMainWindow, WindowMixin):
 
         detect = action('Detect stoma and save', self.detectStoma,
                         'z', 'images', getStr('saveAsDetail'), enabled=False)
-        excel = action('Generate Excel', self.generarExcel,
+        excel = action('Generate Excel', self.generarExcelStoma,
                        'e', 'excel', getStr('saveAsDetail'), enabled=False)
         self.editButton.setDefaultAction(excel)
         trainModel = action('Generate training files', self.trainModel,
@@ -1448,21 +1448,21 @@ class MainWindow(QMainWindow, WindowMixin):
                 self.defaultSaveDir = path
                 self.importDirImages(path)
 
-    def generarExcel(self):
+    def generarExcelStoma(self):
         self.saveFile()
         Dialog = QtWidgets.QDialog()
-        ui = Ui_Dialog1()
-        ui.setupUi1(Dialog)
+        ui1 = Ui_Dialog1()
+        ui1.setupUi1(Dialog)
         x = Dialog.exec_()
-        if ui.genera:
+        if ui1.genera:
             try:
-                generaExcel(os.path.dirname(ustr(self.filePath)), ui.escaStoma, self.shapeSize, ui.uni, ui.che2, ui.che3, ui.che4, ui.che5, ui.che6, ui.che7, ui.che8, ui.che9, ui.che10)
+                generaExcel(os.path.dirname(ustr(self.filePath)), ui1.escaStoma, self.shapeSize, ui1.uni, ui1.che2, ui1.che3, ui1.che4, ui1.che5, ui1.che6, ui1.che7, ui1.che8, ui1.che9, ui1.che10)
                 self.setWindowIcon(QtGui.QIcon("resources/icons/excel.png"))
                 QMessageBox.about(self, "Information", "Excel finished")
                 self.setWindowIcon(newIcon("app"))
             except:
                 QMessageBox.about(self, "Information", "Introduce the value of the scale")
-                self.generarExcel()
+                self.generarExcelStoma()
         # QMessageBox msgBox
         # msgBox.setText("Excel finished")
         # msgBox.exec()
